
local addonName, addonData = ...

local showToonName = true
local showRealmName = showToonName and true
local debugMessages = true

local bnNameFormat = "%s"
local playerBNFormat = "|HBNplayer:%s|h" .. bnNameFormat .. "%s|h"
local playerBNPattern = "|HBNplayer:(.-)|h%[(|Kf(%d+).-)%](.*)|h"

local function RGB_TO_HEX(rgb) 
	return string.format("%02x%02x%02x", rgb.r*255, rgb.g*255, rgb.b*255) 
end

local function ColorToonName(chatFrame,message,...)
	local bnData, bnName, bnID, bnExtra = string.match(message, playerBNPattern)

	if bnData then
		local toonInfo = { BNGetToonInfo(bnID) }
		local link = string.format(playerBNFormat, bnData, bnName, bnExtra or "")

		if toonInfo[3] ~= "WoW" or toonInfo[3] == nil then
			message = string.gsub(message, playerBNPattern, link)
		else
			local toonName = toonInfo[2]
			local realmName = toonInfo[4]
			local class = toonInfo[8]

			local color = RAID_CLASS_COLORS[class]
			local classToken = addonData.ClassNames[class]
			if not color then 
				color = RAID_CLASS_COLORS[classToken] 
			end
			local colorHex = RGB_TO_HEX(color)

			if showToonName then
				if showRealmName then
					coloredSender = string.format("|cff%s %s (%s-%s)|r",colorHex,bnName,toonName,realmName)
				else
					coloredSender = string.format("|cff%s %s (%s)|r",colorHex,bnName,toonName)
				end
			else
				coloredSender = string.format("|cff%s %s|r",colorHex,bnName)
			end

			link = string.format(playerBNFormat, bnData, coloredSender, bnExtra or "")
			message = string.gsub(message, playerBNPattern, link)

		end
	end
	return message
end

local function AddMessage(chatFrame, message, ...)
	if type(message) == "string" then
		local bnData, bnName, bnID, bnExtra = strmatch(message, playerBNPattern)
		if bnData then
			message = ColorToonName(chatFrame,message,...)
		end
	end
	addonData[chatFrame].AddMessage(chatFrame,message, ...)
end

local function OpenTemporaryWindow(...)
	local chatFrame = addonData.FCF_OpenTemporaryWindow(...)
	addonData[chatFrame] = addonData[chatFrame] or {}
	if ( not addonData[chatFrame].AddMessage ) then
		addonData[chatFrame].AddMessage = chatFrame.AddMessage
		chatFrame.AddMessage = AddMessage
	end	
end

addonData.XRICEvents = CreateFrame("Frame")
addonData.XRICEvents:RegisterEvent("ADDON_LOADED")
addonData.XRICEvents:SetScript("OnEvent",function(self,event,...)

	local args = { ... }

	if event == "ADDON_LOADED" and args[1] == addonName then
		addonData.ClassNames = {}
		for k, v in pairs(LOCALIZED_CLASS_NAMES_MALE) do
		        addonData.ClassNames[v] = k
		end
		for k, v in pairs(LOCALIZED_CLASS_NAMES_FEMALE) do
		        addonData.ClassNames[v] = k
		end

		for i = 1, NUM_CHAT_WINDOWS do
			local chatFrame = _G["ChatFrame" .. i]
			addonData[chatFrame] = addonData[chatFrame] or {}
			if ( not addonData[chatFrame].AddMessage ) then
				addonData[chatFrame].AddMessage = chatFrame.AddMessage
				chatFrame.AddMessage = AddMessage
			end
		end

		if ( not addonData.FCF_OpenTemporaryWindow ) then
			addonData.FCF_OpenTemporaryWindow = FCF_OpenTemporaryWindow
			FCF_OpenTemporaryWindow = OpenTemporaryWindow
		end


	end

end)
